//
//  DogPlayerObject.m
//  Boise_Demo
//
//  Created by Jared Halpern on 3/7/12.
//  Copyright 2012 __MyCompanyName__. All rights reserved.
//

#import "DogPlayerObject.h"


@implementation DogPlayerObject

@synthesize runNorthAnim;
@synthesize runNorthEastAnim;
@synthesize runEastAnim;
@synthesize runSouthEastAnim;
@synthesize runSouthAnim;
@synthesize runSouthWestAnim;
@synthesize runWestAnim;
@synthesize runNorthWestAnim;

@synthesize playerLife;


-(void)dealloc{
    
    [runNorthAnim release];
    [runNorthEastAnim release];
    [runEastAnim release];
    [runSouthEastAnim release];
    [runSouthAnim release];
    [runSouthWestAnim release];
    [runWestAnim release];
    [runNorthWestAnim release];
    
    [super dealloc];
}

-(id)init{
    
    self = [super init];
    if (self != nil) {
     
        [self setGameObjectType:kGameObjTypePlayer];
        
        [self initAnimationsForObject];
        [self changeState:kStateRunNorth];
        
        // initialize with full life
        [self setPlayerLife:100.0];
        [self setObjectState:kStateAlive];
    }
    
    return self;
}

-(void)initAnimationsForObject{
    
    [self setRunNorthAnim:[self loadPlistForAnimationWithName:@"runNorthAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunNorthEastAnim:[self loadPlistForAnimationWithName:@"runNorthEastAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunEastAnim:[self loadPlistForAnimationWithName:@"runEastAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunSouthEastAnim:[self loadPlistForAnimationWithName:@"runSouthEastAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunSouthAnim:[self loadPlistForAnimationWithName:@"runSouthAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunSouthWestAnim:[self loadPlistForAnimationWithName:@"runSouthWestAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunWestAnim:[self loadPlistForAnimationWithName:@"runWestAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    [self setRunNorthWestAnim:[self loadPlistForAnimationWithName:@"runNorthWestAnim" 
                                                 andClassName:NSStringFromClass([self class])]];
    
}

#pragma mark -
#pragma mark Game Loop

-(void)updateStateWithDeltaTime:(ccTime)deltaTime andListOfGameObjects:(CCArray *)gameObjects{
}    

-(void)changeState:(ObjectStates)newState{
    
    if (objectState == kStateDead){
        // nothing else to do since player is dead;
        CCLOG(@"DogPlayerObject: kStateDead");
        return;
    }
    
    [self stopAllActions];
    [self setObjectState:newState];
   
    id action = nil; // we'll fill this with something, depending on the state change
    
    switch (newState) {
            
        case kStateDead:
        {
            CCLOG(@"DogPlayerObject: kStateDead");
            break;
        }
        case kStateRunNorth:
        {
            CCLOG(@"DogPlayerObject: kStateRunNorth");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runNorthAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunNorthEast:
        {
            CCLOG(@"DogPlayerObject: kStateRunNorthEast");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runNorthEastAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunEast:
        {
            CCLOG(@"DogPlayerObject: kStateRunEast");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runEastAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunSouthEast:
        {
            CCLOG(@"DogPlayerObject: kStateRunSouthEast");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runSouthEastAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunSouth:
        {
            CCLOG(@"DogPlayerObject: kStateRunSouth");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runSouthAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunSouthWest:
        {
            CCLOG(@"DogPlayerObject: kStateRunSouthWest");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runSouthWestAnim restoreOriginalFrame:NO]];
            break;
        }   
        case kStateRunWest:
        {
            CCLOG(@"DogPlayerObject: kStateRunWest");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runSouthAnim restoreOriginalFrame:NO]];
            break;
        }
        case kStateRunNorthWest:
        {
            CCLOG(@"DogPlayerObject: kStateRunNorthWest");
            action = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:runNorthWestAnim restoreOriginalFrame:NO]];
            break;
        }
        default:
        {
            CCLOG(@"DogPlayerObject: unhandled state");
            break;
        }
    }
    
    if (action != nil)
        [self runAction:action];
    
}

@end





