//
//  EnemyObject.m
//  Boise_Demo
//
//  Created by Jared Halpern on 3/7/12.
//  Copyright 2012 __MyCompanyName__. All rights reserved.
//

#import "EnemyObject.h"


@implementation EnemyObject

@synthesize moveEastAnim;
@synthesize eatEastAnim;
@synthesize dieEastAnim;

-(void)dealloc{
    
    [moveEastAnim release];
    [eatEastAnim release];
    [dieEastAnim release];
    
    [super dealloc];
}


-(id)init{
    
    self = [super init];
    if(self != nil){
        
        [self setGameObjectType:kGameObjTypeEnemy];
        [self initAnimationsForObject];
        [self changeState:kStateAlive];
        
    }
    
    return self;
}


-(void)initAnimationsForObject{
    
    // change hardcoding of objectname
    // we'll have more then one enemytype eventually
    
    [self setMoveEastAnim:[self loadPlistForAnimationWithName:@"moveEastAnim" 
                                                 andClassName:@"SlugObject"]];
    
    [self setEatEastAnim:[self loadPlistForAnimationWithName:@"eatEastAnim" 
                                                 andClassName:@"SlugObject"]];
    
    [self setDieEastAnim:[self loadPlistForAnimationWithName:@"dieEastAnim" 
                                                 andClassName:@"SlugObject"]];

}

#pragma mark -
#pragma mark Game Loop

-(void)updateStateWithDeltaTime:(ccTime)deltaTime andListOfGameObjects:(CCArray *)gameObjects{
    
    if ([self isAlive] == NO) {
        [self changeState:kStateDead];
        return;
    }
    
    // do line of sight calculations to see if enemy can see where player is
    // OR just start moving towards him

}    

-(void)changeState:(ObjectStates)newState{
    
    [self stopAllActions];
    [self setObjectState:newState];
    
    id actionMove = nil; // we'll fill this with something, depending on the state change
    id actionAnim = nil;
    
    switch (newState) {
            
        case kStateAlive:
        {
            CCLOG(@"EnemyObject: kStateAlive");
            [self setIsAlive:YES];
            break;
        }   
        case kStateDead:
        {
            CCLOG(@"EnemyObject: kStateDead");
            [self setIsAlive:NO];
            [self setVisible:NO];
            [self removeFromParentAndCleanup:YES];            
            
            // cleanup Box2D
            body->GetWorld()->DestroyBody(body);
            body = NULL;
            
            break;            
        }   
        case kStateRunEast:
        {
            CCLOG(@"EnemyObject: running east");
            actionAnim = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:moveEastAnim restoreOriginalFrame:NO]];
            
//            actionMove = [CCMoveTo actionWithDuration:1.0 position:oldDest];
            
            break;
        }
        case kStateRunWest:
        {
            CCLOG(@"EnemyObject: running west");
            actionAnim = [CCRepeatForever actionWithAction: 
                      [CCAnimate actionWithAnimation:moveEastAnim restoreOriginalFrame:NO]];
        //id actionFlipX = [CCFlipX actionWithFlipX:YES];
            
            break;
        }
            
        default:
            CCLOG(@"EnemyObject: unhandled state");
            break;
    }
    
    if (actionAnim != nil)
        [self runAction:actionAnim];
    
    if (actionMove != nil)
        [self runAction:actionMove];
    
}



@end
