//
//  GameManager.m
//  Boise_Demo
//
//  Created by Jared Halpern on 3/2/12.
//  Copyright 2012 __MyCompanyName__. All rights reserved.
//

#import "GameManager.h"


@implementation GameManager

@synthesize isMusicOn;
@synthesize isSoundOn;
@synthesize playerDied;


static GameManager* _sharedGameManager = nil;


+(GameManager*)sharedGameManager{
    
    // sync block
    @synchronized([GameManager class])
    {
        if(!_sharedGameManager)
            
            [[self alloc] init];
        
        return _sharedGameManager;
    }
    return nil;
}

+(id)alloc {
    @synchronized ([GameManager class])
    {
        NSAssert(_sharedGameManager == nil, @"GameManager: Attempted to allocate a second instance of the Game Manager singleton.");
        
        _sharedGameManager = [super alloc];
        
        return _sharedGameManager;
    }
    return nil;
}

-(id)init{
    
    self = [super init];
    
    if (self != nil){
        
        //initialized
        CCLOG(@"GameManager: Game Manager Singleton initialized!");
        
        //start with on by default
        isMusicOn = YES;
        isSoundOn = YES;
        playerDied = NO;
        currentScene = kSceneTypeNoSceneUninitialized;
        
    }
    
    return self;
}

-(void) runSceneWithID:(SceneTypes)sceneID{
    
    // save the old scene in case we have to revert back
    SceneTypes oldScene = currentScene;
    
    currentScene = sceneID;
    
    id sceneToRun = nil;
    
    switch (sceneID) {
            
        // additional scenes would display the menu, options, etc
            
        case kSceneTypeGame:
        {
            sceneToRun = [GameScene node];
            
            CCLOG(@"GameManager: running GameScene");
            
            break;
        }   
        case kSceneTypeMainMenu:
        {
            CCLOG(@"GameManager: running MainMenu Scene");            
            break;
        }
        case kSceneTypeOptions:
        {
            CCLOG(@"GameManager: running Options Scene");
            break;
        }
        case kSceneTypeIntro:
        {
            CCLOG(@"GameManager: running Intro Scene");
            break;
        }
        case kSceneTypeDeath:
        {
            CCLOG(@"GameManager: running Death Scene");
            break;
        }            
        default:
        {   
            CCLOG(@"GameManager: Unknown sceneID. Cannot Switch Scenes. Get your act together man!");
            
            break;
        }
    }
    
    if (sceneToRun == nil) {
        
        //revert back since no new scene
        
        currentScene = oldScene;
        
        CCLOG(@"GameManager: unknown scene homie...");
        
        return;
    }
    
    // put code to resize screen here for iPad / older iPhones
    
    if ([[CCDirector sharedDirector] runningScene] == nil){
        
        [[CCDirector sharedDirector] runWithScene:sceneToRun];
        
    } else {
        
        [[CCDirector sharedDirector] replaceScene:sceneToRun];
    }
}

-(CGSize)getDimensionsOfCurrentScene{
    
    CGSize screenSize = [[CCDirector sharedDirector] winSize];
    CGSize levelSize;
    
    switch (currentScene) {
            
        case kSceneTypeNoSceneUninitialized:
        {
            levelSize = screenSize;
            break;
        }
        case kSceneTypeGame:
        {
            // obviously this hardcoded #define approach is only meant for a prototype with one level
            levelSize = CGSizeMake(screenSize.width * 4.0f, screenSize.height*4.0f);
            break;
        }   
        default:
        {
            CCLOG(@"GameManager: Unknown Scene.");
            levelSize = screenSize;            
            break;
        }
    } //switch
//    CCLOG(@"level size: %g, %g:", levelSize.width, levelSize.height);

    return levelSize;
}


@end
