//
//  GameObject.m
//  Boise_Demo
//
//  Created by Jared Halpern on 3/3/12.
//  Copyright 2012 __MyCompanyName__. All rights reserved.
//
// A generic game object from which all other game objects will inherit

#import "GameObject.h"

@implementation GameObject

@synthesize gameObjectType;
@synthesize statusLabel;
@synthesize isAlive;
@synthesize objectState;
@synthesize delegate;

-(void)dealloc{
    
    delegate = nil;
    [super dealloc];
}


-(id)init{
    
    self = [super init];
    if (self != nil){
        
        [self setIsAlive:YES];
        
    }
    
    return self;
}

-(void)checkAndClampSpritePosition{
//     used to ensure the sprite doesn't go running offscreen
    
//    CGPoint currentSpritePosition = [self position];
//    CGSize levelSize = [[GameManager sharedGameManager]getDimensionsOfCurrentScene];
}

-(CGRect)adjustedBoundingBox{

    // using Box2D sensors instead of cocos2d bounding boxes.

//    CCLOG(@"GameObject: should override adjustedBoundingBox");

    CGRect boundingBox = [self boundingBox];
    return boundingBox;
}

-(void)changeState:(ObjectStates)newState{
    
    CCLOG(@"GameObject: should override changeState");
}

-(void)updateStateWithDeltaTime:(ccTime)deltaTime andListOfGameObjects:(CCArray *)gameObjects{
    
}

-(CCAnimation*)loadPlistForAnimationWithName:(NSString*)animationName andClassName:(NSString*)className {
    
    CCAnimation *animationToReturn = nil;
    NSString *fullFileName = 
    [NSString stringWithFormat:@"%@.plist",className];
    NSString *plistPath;
    
    // Get the Path to the plist file
    NSString *rootPath = 
    [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
    
    plistPath = [rootPath stringByAppendingPathComponent:fullFileName];
    
    if (![[NSFileManager defaultManager] fileExistsAtPath:plistPath]) {
        plistPath = [[NSBundle mainBundle] 
                     pathForResource:className ofType:@"plist"];
    }
    
    // Read in the plist file
    NSDictionary *plistDictionary = 
    [NSDictionary dictionaryWithContentsOfFile:plistPath];
    
    // if the plistDictionary was null, the file wasn't found.
    if (plistDictionary == nil) {
        CCLOG(@"Error reading plist: %@.plist", className);
        return nil; // No Plist Dictionary or file found
    }
    
    // get just the mini-dictionary for this animation
    NSDictionary *animationSettings = 
    [plistDictionary objectForKey:animationName];
    if (animationSettings == nil) {
        CCLOG(@"Could not locate AnimationWithName:%@",animationName);
        return nil;
    }
    
    // get the delay value for the animation
    float animationDelay = 
    [[animationSettings objectForKey:@"delay"] floatValue];
    animationToReturn = [CCAnimation animation];
    [animationToReturn setDelay:animationDelay];
    
    // add the frames to the animation
    NSString *animationFramePrefix = 
    [animationSettings objectForKey:@"filenamePrefix"];
    NSString *animationFrames = 
    [animationSettings objectForKey:@"animationFrames"];
    NSArray *animationFrameNumbers = 
    [animationFrames componentsSeparatedByString:@","];
    
    for (NSString *frameNumber in animationFrameNumbers) {
        NSString *frameName = 
        [NSString stringWithFormat:@"%@%@.png",
         animationFramePrefix,frameNumber];
        [animationToReturn addFrame:
         [[CCSpriteFrameCache sharedSpriteFrameCache] 
          spriteFrameByName:frameName]];
    }
    
    return animationToReturn;
}


@end
