//
//  GameplayLayer.h
//  Boise_Demo
//
//  Created by Jared Halpern on 3/2/12.
//  Copyright 2012 __MyCompanyName__. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "cocos2d.h"
#import "GLES-Render.h"
#import "Box2D.h"

#import "GameManager.h"
#import "GameObject.h"
#import "DogPlayerObject.h"
#import "EnemyObject.h"
#import "PowerupObject.h"

#import "SimpleAudioEngine.h"

@interface GameplayLayer : CCLayer <CCTargetedTouchDelegate, GameplayLayerDelegate>{
    
    CGSize screenSize;
    CCSpriteBatchNode *gameSceneSpriteBatchNode;
    DogPlayerObject *playerObject;
    CCProgressTimer *tempHealthBar;    
    
    // Box2D
    b2World *world;
    GLESDebugDraw *debugDraw;
    b2Body *groundBody;
    b2MouseJoint *mouseJoint;  
    b2Body *playerBody;
    
    CCParticleSystem *fireEmitter;
    CCParticleSystem *smokeEmitter;
    
    double idleTimeStart; // used to measure idle time
    
}

@property (nonatomic, retain) CCParticleSystem *fireEmitter;
@property (nonatomic, retain) CCParticleSystem *smokeEmitter;

// setup and creation related
-(void)setupLevel;
-(void)resetLevel;
-(void)gameOver;
-(void)startMusic;
-(void)createPlayer;
-(void)createRandomEnemy;
-(void)createPowerup;
-(void)createSmallFires;

// game loop related
-(void)updateHealthbar:(float)newPercentage;
-(void)scrollLayer;
-(void)setDogPlayerPosition:(CGPoint)position;

// Box2D related
-(void)setupBox2DWorld;
-(void)setupDebugDraw;

@end


